@keyframes squirrelAnimation {
    0% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    2% {
        transform: translateX(0) rotateY(180deg) rotateZ(0deg) scaleY(1);
    }
    3% {
        transform: translateX(-20%) rotateY(180deg) rotateZ(15deg) scaleY(0.9);
    }
    4% {
        transform: translateX(0) rotateY(180deg) rotateZ(0deg) scaleY(1);
    }
    10% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    12% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    13% {
        transform: rotateY(0deg) rotateZ(15deg);
    }
    14% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    22% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    24% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    46% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    48% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    60% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    62% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    72% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    60% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    62% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    64% {
        transform: rotateY(180deg) rotateZ(0deg) scaleY(1);
    }
    65% {
        transform: rotateY(180deg) rotateZ(0deg) scaleY(1.1);
    }
    66% {
        transform: rotateY(180deg) rotateZ(0deg) scaleY(1);
    }

    72% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    74% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    75% {
        transform: rotateY(0deg) rotateZ(15deg);
    }
    76% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    80% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    82% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    88% {
        transform: rotateY(180deg) rotateZ(0deg);
    }
    90% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
    100% {
        transform: rotateY(0deg) rotateZ(0deg);
    }
}


.squirrel-icon {
    animation: squirrelAnimation 8s infinite;
    transform-origin: center;
    transform-style: preserve-3d;
    backface-visibility: visible;
}

.squirrel-icon:hover {
    animation-play-state: paused;
}